@@ -103,16 +103,10 @@ def text_dialog(password=False):
 def touchselectorentry_dialog():
     global window, current_buhtoon, current_specifier_number
 
-    lst_key = 'touchselectorentry-list' + str(current_specifier_number) or ''
+    lst_key = 'touchselectorentry-list' + str(current_specifier_number or '') 
     
     dialog = gtk.Dialog('', window)
     selector = hildon.TouchSelectorEntry(text=True)
-    # selector = hildon.touch_selector_entry_new_text()
-
-    # def f(a,b):
-    #     print a
-    #     print b
-    # selector.connect('changed', f)
     selector.get_entry().connect('activate', response_to_dialog, dialog, gtk.RESPONSE_OK)
     if current_buhtoon:
         if current_buhtoon.get(lst_key):
